@@ -1,11 +1,11 @@
 """History manager extension for the standard Python shell and IPython"""
 
-__version__ = '0.0.3'
+__version__ = '0.1.0'
 
 import curses
 import sys
 
-from pyhstr.application import main, IS_IPYTHON
+from pyhstr.application import IS_IPYTHON, main
 
 hh = object()
 original = sys.displayhook
@@ -22,7 +22,7 @@ else:
     from IPython.core.magic import register_line_magic
 
     @register_line_magic
-    def hh(line):
+    def hh(line): # pylint: disable=function-redefined,unused-argument
         """
         This line magic mirrors the behaviour of sys.displayhook
         in the regular Python shell. Use %hh to invoke.
